# C чего начать

## Установка

Чтобы установить актуальную версию клиента, воспользуйтесь командой:

```text
pip install -U yatracker
```

## Инициализация и завершение работы

Импортируйте библиотеку

```python
from yatracker import YaTracker
```

Создайте экземпляр, передав в конструктор класса необходимые секреты

```python
from yatracker import YaTracker

tracker = YaTracker(org_id=..., token=...) # (1)
```

1. Не сохраняйте свои учётные данные прямо в коде. Используйте переменные окружения.

Для работы с одной организацией достаточного одного клиента.
Вы один раз создаёте его и далее повторно используете его при необходимости.

Не забудьте завершить работу клиента при закрытии вашего приложения

```python
async def on_shutdown():
    await tracker.close()

```


## Использование

!!! note "Обратите внимание"

    Все методы `YaTracker`, вызывающие API, являются асинхронными.
    Ссоответственно, вызывать их нужно внутри корутин.
    Но для упрощения примеров они будут использованы напрямую, как будто мы находимся уже внутри функции.

    Т.е. вместо
    ```python
    async def foo(...):
        await method(...)
    ```
    Мы будем писать
    ```python
    await method(...)
    ```



Для начала создадим новую задачу в очереди для писателей
```python
issue = await tracker.create_issue('Написать шедевр', 'WRITERS') # (1)
```

1. `WRITERS` – ключ очереди

Дополним задачу описанием
```python
issue = await tracker.edit(
    issue_id='WRITERS-1',
    description='... или нечто ценное' # (1)
)

```

1. Описание можно было задать ещё при создании, а здесь это лишь повод для редактирования.

Если вам известен ключ задачи, то нетрудно её получить

```python
issue = await tracker.get_issue('WRITERS-42')
```
